Changelog
=========

1.1 (unreleased)
----------------

- make sure to use correct url of tile
  [vangheem]

- handle not found errors while rendering tiles so layout
  isn't borked
  [vangheem]

1.0 (2012-06-23)
----------------

- initial release.
  [garbas]
